function poissbinom, p_m

  ;Calculates the probability distribution for a Poisson Binomial Distribution
  ;for k successes out of N tries, where each try has independent unique
  ;probability p_m.  p_m is an input vector w/ length equal to the number
  ;of "tries".
  
  ;A brute force calculation is impossible b/c the combinatorics require
  ;an impossibly large number of calculations for modest N. So we use
  ;the discrete Fourier transform.

  N = n_elements(p_m)
  p_k = dcomplexarr(N+1)
  theta = 2*!dpi / (N+1.)
  l = dindgen(N+1)
  product_factor = dcomplexarr(N+1)
  for i=0,N do product_factor[i] = product((1+(dcomplex(cos(theta*l[i]),sin(theta*l[i]))-1)*p_m))
  for k=0,N do p_k[k] = (1./(N+1.)) * total(dcomplex(cos(-theta*l*k),sin(-theta*l*k)) * product_factor)
  p_k = real_part(p_k)

  return,p_k

end
